<?php
namespace Teknisa\CRM\Controller;

use Teknisa\CRM\Controller\TeknisaCrud;
use Doctrine\ORM\EntityManager;
use Zeedhi\Framework\DataSource\DataSet;
use Zeedhi\Framework\DTO\Request\Row;
use Zeedhi\Framework\Util\Functions;

class Questionario {

    protected  $entityManager;
    protected  $newCode;

    public function __construct(EntityManager $entityManager, $newCode)
    {
        $this->entityManager = $entityManager;
        $this->newCode       = $newCode;
    }


	public function get($request, $response)
    {
        $filter = $request->getFilterCriteria()->getConditions();
        $data = array(
            "NRORG"          => $filter[0]['value'],
            "NRAVALIACAO"    => $filter[1]['value'],
            "NRPARCEXECAVAL" => $filter[2]['value'],
            "NRPARCAVALIADO" => $filter[3]['value']);

        $obj   = $this->constroiObjeto($data);
		$response->addDataSet(new DataSet("/questionario/get",array($obj)));
	}

	public function save(Row $request)
	{
        $dataset         = $request->getRow();
        $nrorg           = $dataset["NRORG"];
		$cdoperador      = $dataset["CDOPERADOR"];
		$nravaliacao     = $dataset["NRAVALIACAO"];
		$nrparcavaliado  = $dataset["NRPARCAVALIADO"];
		$nrparcexecaval  = $dataset["NRPARCEXECAVAL"];

        foreach ($dataset["answers"] as $questao => $resposta)
        {
			$nrquestao = str_replace("QUESTAO_", "", $questao);
            $nrexecavaliacao = self::retornaExecavaliacao($nrparcavaliado,$nravaliacao,$nrquestao, $nrparcexecaval);
            $resposta = self::recebeRespostas($nrquestao, $nrorg, $resposta);

            $sql = "INSERT INTO RESPAVALIACAO
                                    (NRRESPAVALIACAO, NRORG, NREXECAVALIACAO, NRRESPOSTA, TXRESPAVALIACAO,
                                     TXOBSCORRECAVAL, VRNOTARESPAVAL, DTINCLUSAO, DTULTATU, NRORGINCLUSAO,
                                     CDOPERINCLUSAO, NRORGULTATU, CDOPERULTATU, IDATIVO, DTRESPAVALIACAO,
                                     VRRESPAVALIACAO)
                             VALUES (:NRRESPAVALIACAO, :NRORG, :NREXECAVALIACAO, :NRRESPOSTA, :TXRESPAVALIACAO,
                                     :TXOBSCORRECAVAL, NULL, SYSDATE, NULL, :NRORG,
                                     :CDOPERADOR, NULL, NULL, :IDATIVO, SYSDATE, null)";

            $std = $this->entityManager->getConnection()->prepare($sql);

            foreach($resposta as $resp)
            {
                $nrrespavaliacao = $this->newCode->getCodeByTableName("RESPAVALIACAO", $nrorg);
                $params = array(
                    "NRRESPAVALIACAO"=>(int)$nrrespavaliacao,
                    "NRORG"=>(int)$nrorg,
                    "NREXECAVALIACAO" =>(int) $nrexecavaliacao,
                    "NRRESPOSTA" =>  $resp['numero'],
                    "TXRESPAVALIACAO" => $resp['valor'],
                    "TXOBSCORRECAVAL" => '',
                    "CDOPERADOR" => $cdoperador,
                    "IDATIVO"    => "S"
                );

                $std->execute($params);
           }
        }

        $sql = "UPDATE EXECAVALIACAO
		           SET DTEXECUCAOAVAL = SYSDATE
		         WHERE NRAVALIACAO    = :NRAVALIACAO
		           AND NRPARCEXECAVAL = :NRPARCEXECAVAL
		           AND NRPARCAVALIADO = :NRPARCAVALIADO
		           AND NRORG          = :NRORG";

        $std = $this->entityManager->getConnection()->prepare($sql);
        $std->execute(array(
            "NRPARCAVALIADO" => $nrparcavaliado,
            "NRPARCEXECAVAL" => $nrparcexecaval,
            "NRAVALIACAO"    => $nravaliacao,
            "NRORG"          => $nrorg,
        ));

		if ($dataset["concluir"] === true)
        {
			self::enviar($nravaliacao, $nrparcexecaval, $nrparcavaliado, $nrorg);
        }

	}

    private function recebeRespostas($questao, $nrorg, $respostas)
    {
        $select = "SELECT *
                     FROM RESPOSTA
                    WHERE NRQUESTAO = :NRQUESTAO
                      AND NRORG     = :NRORG";

        $std = $this->entityManager->getConnection()->prepare($select);
        $std->execute(array("NRQUESTAO"=>(int)$questao,"NRORG"=>(int)$nrorg));

        $result = $std->fetchAll();

        if(count($result) > 0)
        {
            if(\Zeedhi\Framework\Util\Functions::arrayKeyExists("options", $respostas))
            {
                $ar = array();
                foreach($respostas["options"] as $num => $desc)
                {
                    if($desc == true)
                    {
                        $ar[] = array("numero" => $num, "valor" => self::retornaDsresposta($num));
                    }
                }

                return $ar;
            }
            else
            {
                return array(array("numero" => $respostas["value"], "valor" => self::retornaDsresposta($respostas["value"])));
            }
        }
        else
        {
            return array(array("numero" => null, "valor" => $respostas["value"]));
        }
    }

    private function retornaExecavaliacao($nrparcavaliado,$nravaliacao,$nrquestao,$nrparcexecaval)
    {
        $sql = "SELECT NREXECAVALIACAO
                  FROM EXECAVALIACAO
                 WHERE NRPARCAVALIADO  = :NRPARCAVALIADO
                   AND NRAVALIACAO     = :NRAVALIACAO
                   AND NRQUESTAO       = :NRQUESTAO
                   AND NRPARCEXECAVAL  = :NRPARCEXECAVAL";

        $std = $this->entityManager->getConnection()->prepare($sql);
        $std->execute(array("NRPARCAVALIADO"=>(int)$nrparcavaliado, "NRAVALIACAO"=>(int)$nravaliacao,"NRQUESTAO"=>(int)$nrquestao,"NRPARCEXECAVAL"=>(int)$nrparcexecaval));

        $result = $std->fetchAll();

        return $result[0]['NREXECAVALIACAO'];
    }

    private function retornaDsresposta($resposta)
    {
        $sql = "SELECT DSRESPOSTA
                  FROM RESPOSTA
                 WHERE NRRESPOSTA = :NRRESPOSTA";

        $std = $this->entityManager->getConnection()->prepare($sql);
        $std->execute(array("NRRESPOSTA"=>(int)$resposta));
        $result = $std->fetchAll();

        return $result[0]['DSRESPOSTA'];
    }

    public function retornaRespostaAvaliacao($nrexecavaliacao)
    {
        $sql    = "SELECT NRRESPAVALIACAO
		             FROM RESPAVALIACAO
		            WHERE NREXECAVALIACAO = :NREXECAVALIACAO";

        $std = $this->entityManager->getConnection()->prepare($sql);
        $std->execute(array("NREXECAVALIACAO"=>(int)$nrexecavaliacao));

        $result = $std->fetchAll();
        return $result;
    }

	private function enviar($nravaliacao, $nrparcexecaval, $nrparcavaliado, $nrorg)
    {
        $sql = "UPDATE PARTICIPAVAL
			  	   SET IDSITUACAOAVAL  = :IDSITUACAOAVAL,
			  	       DTCONCLUSAOAVAL = SYSDATE
				 WHERE NRAVALIACAO     = :NRAVALIACAO
				   AND NRPARCEXECAVAL  = :NRPARCEXECAVAL
				   AND NRPARCAVALIADO  = :NRPARCAVALIADO
				   AND NRORG           = :NRORG";

        $std = $this->entityManager->getConnection()->prepare($sql);
        $std->execute(array(
            "NRPARCAVALIADO" => $nrparcavaliado,
            "NRPARCEXECAVAL" => $nrparcexecaval,
            "NRAVALIACAO"    => $nravaliacao,
            "NRORG"          => $nrorg,
            "IDSITUACAOAVAL" => "CONCLUIDA"
        ));

    	$sql2 = "UPDATE AVALIACAOGERAL
			  	    SET IDSITUACAOAVALIACAO = :IDSITUACAOAVALIACAO,
			  	  	    DTFIMINSCRIAVAL     = SYSDATE
				  WHERE NRAVALIACAO         = :NRAVALIACAO
				    AND NRORG               = :NRORG";

        $std = $this->entityManager->getConnection()->prepare($sql2);
        $std->execute(array(
            "NRAVALIACAO"    => $nravaliacao,
            "NRORG"          => $nrorg,
            "IDSITUACAOAVALIACAO" => "CONCLUIDA"
        ));
	}

	public function constroiObjeto($dados = array())
	{
		$obj = array();
		$cabecalhoQuestionario = $this->getCabecalhoQuestionario($dados["NRAVALIACAO"], $dados["NRORG"]);

		$obj["name"]        = $cabecalhoQuestionario["NMAVALIACAO"];
		$obj["description"] = $cabecalhoQuestionario["NMAVALIACAO"];

		$questoes           = $this->getQuestoes (
			$dados["NRAVALIACAO"],
			$dados["NRORG"],
			$dados["NRPARCEXECAVAL"],
			$dados["NRPARCAVALIADO"]
		);

		if (count($questoes)>0)
        {
			$obj["questions"] = array();
			foreach ($questoes as $questao)
            {
				$indice = count($obj["questions"]);
				$obj["questions"][$indice]["type"]                    = $questao["TIPO"];
				$obj["questions"][$indice]["description"]             = $questao["TXQUESTAO"];
				$obj["questions"][$indice]["name"]                    = $questao["QUESTION_NAME"];
				$obj["questions"][$indice]["required"]                = true;
				$obj["questions"][$indice]["seqno"]                   = $questao["NRORDEQUESTAVAL"];
				$alternativas = $this->getAlternativasQuestoes($questao["NRQUESTAO"], $dados["NRORG"]);

				if ((count($alternativas)>0) && (is_array($alternativas)))
                {
					$obj["questions"][$indice]["options"] = array();
					foreach ($alternativas as $alternativa)
                    {
						$indiceOpt = count($obj["questions"][$indice]["options"]);

                        $obj["questions"][$indice]["options"] = self::constroiOpcoes($obj["questions"][$indice]["options"],$questao["TIPO"], $indiceOpt, $alternativa);
                    }
                }
			}
		}

        $sql = "SELECT 'QUESTAO_'||EXECAVALIACAO.NRQUESTAO AS QUESTAO,
                       DECODE(RESPAVALIACAO.NRRESPOSTA, NULL, RESPAVALIACAO.TXRESPAVALIACAO, RESPAVALIACAO.NRRESPOSTA) AS  RESPOSTA,
                       QUESTAO.IDOPCAORESPOSTA AS ID
				  FROM EXECAVALIACAO
			     INNER JOIN RESPAVALIACAO
				    ON RESPAVALIACAO.NREXECAVALIACAO = EXECAVALIACAO.NREXECAVALIACAO
                   AND RESPAVALIACAO.NRORG           = EXECAVALIACAO.NRORG
                 INNER JOIN QUESTAO
                    ON QUESTAO.NRQUESTAO = EXECAVALIACAO.NRQUESTAO
                   AND QUESTAO.NRORG = EXECAVALIACAO.NRORG
				 WHERE EXECAVALIACAO.NRORG           = :NRORG
				   AND EXECAVALIACAO.NRAVALIACAO     = :NRAVALIACAO
				   AND EXECAVALIACAO.NRPARCAVALIADO  = :NRPARCAVALIADO
				   AND EXECAVALIACAO.NRPARCEXECAVAL  = :NRPARCEXECAVAL";
        $params = array(
            "NRPARCAVALIADO" => $dados["NRPARCAVALIADO"],
            "NRPARCEXECAVAL" => $dados["NRPARCEXECAVAL"],
            "NRAVALIACAO"    => $dados["NRAVALIACAO"],
            "NRORG"          => $dados["NRORG"]
        );

        $dataset = $this->entityManager->getConnection()->fetchAll($sql, $params);

        if (count($dataset)>0)
        {
			$respostas = array();
			foreach ($dataset as $row)
            {
                if($row["ID"] == "UNICA")
                {
                    $respostas[$row["QUESTAO"]] = array("value" => $row["RESPOSTA"]);
                }
                else
                {
                    $respostas[$row["QUESTAO"]]["options"][$row["RESPOSTA"]] = true;
                }
			}

			$obj["answer"] = $respostas;
		}

        return $obj;
	}

	private function getCabecalhoQuestionario($nravaliacao, $nrorg)
	{
		$sql = "SELECT AVALIACAOGERAL.NMAVALIACAO
				  FROM AVALIACAOGERAL
				 WHERE NRAVALIACAO = :NRAVALIACAO
				   AND NRORG       = :NRORG";
		$params  = array (
			"NRAVALIACAO" => $nravaliacao,
            "NRORG"         => $nrorg
		);

        $dataset = $this->entityManager->getConnection()->fetchAll($sql, $params);
        return $dataset[0];
	}

	private function getQuestoes($nravaliacao, $nrorg, $nravaliador, $nravaliado)
	{
		$sql = "SELECT QUESTAO.NRQUESTAO,
				       AVALIACAOGERAL.NRAVALIACAO,
				       QUESTAO.TXQUESTAO,
				       'QUESTAO_'||QUESTAO.NRQUESTAO AS QUESTION_NAME,
				       'false' AS QUESTION_ALTERNATIVE_OPTION,
				       DECODE(QUESTAO.IDQUESTAOOBRIGA, 'S', 'true', 'false') AS QUESTAO_REQUIRED,
				       QUESTAVALIACAO.NRORDEQUESTAVAL,
				       (CASE QUESTAO.IDTIPOQUESTAO
                        WHEN 'FECHADA'      THEN DECODE(QUESTAO.IDOPCAORESPOSTA, 'UNICA','unique', 'multiple')
                        WHEN 'ABERTA_TEXTO' THEN 'large_text'
                        WHEN 'ABERTA_VALOR' THEN 'short_text'
                        WHEN 'ABERTA_DATA'  THEN 'datetime'
                        END) AS TIPO
				  FROM QUESTAVALIACAO,
				       QUESTAO,
				       EXECAVALIACAO,
				       AVALIACAOGERAL
				 WHERE QUESTAVALIACAO.NRQUESTAO       = QUESTAO.NRQUESTAO
                   AND QUESTAVALIACAO.NRAVALIACAO     = AVALIACAOGERAL.NRAVALIACAO
                   AND QUESTAVALIACAO.NRAVALIACAO     = EXECAVALIACAO.NRAVALIACAO
				   AND QUESTAO.NRQUESTAO              = EXECAVALIACAO.NRQUESTAO
				   AND QUESTAO.NRQUESTAO              = QUESTAVALIACAO.NRQUESTAO
				   AND AVALIACAOGERAL.NRAVALIACAO     = EXECAVALIACAO.NRAVALIACAO
				   AND EXECAVALIACAO.NRPARCAVALIADO   = :NRPARCAVALIADO
				   AND EXECAVALIACAO.NRAVALIACAO      = :NRAVALIACAO
				   AND EXECAVALIACAO.NRPARCEXECAVAL   = :NRPARCEXECAVAL
				   AND EXECAVALIACAO.NRORG            = :NRORG
				 ORDER BY NRORDEQUESTAVAL";

		$params = array(
			"NRPARCAVALIADO" => $nravaliado,
			"NRPARCEXECAVAL" => $nravaliador,
			"NRAVALIACAO"    => $nravaliacao,
			"NRORG"          => $nrorg,
		);

		return $this->entityManager->getConnection()->fetchAll($sql, $params);
	}

	public function getAlternativasQuestoes($nrquestao, $nrorg)
	{
		$sql = "SELECT DSRESPOSTA,
                       NRRESPOSTA,
                       VRPESORESPOSTA,
                       NRORDENARESPOST
				  FROM RESPOSTA
				 WHERE NRQUESTAO = :NRQUESTAO
				   AND NRORG     = :NRORG
				 ORDER BY NRORDENARESPOST";

		$params = array(
			"NRQUESTAO" => $nrquestao,
			"NRORG"     => $nrorg,
		);

        return $this->entityManager->getConnection()->fetchAll($sql, $params);
	}

    public function constroiOpcoes($opcoes, $tipo, $indice, $alternativa)
    {
        switch($tipo)
        {
            case 'unique':
                $opcoes[$indice]["value"]       = $alternativa["NRRESPOSTA"];
                $opcoes[$indice]["description"] = $alternativa["DSRESPOSTA"];
                $opcoes[$indice]["seqno"]       = $alternativa["NRORDENARESPOST"];
                break;
            case 'multiple':
                $opcoes[$indice]["id"]          = $alternativa["NRRESPOSTA"];
                $opcoes[$indice]["description"] = $alternativa["DSRESPOSTA"];
                break;
        }

        return $opcoes;
    }
}