<?php
namespace Teknisa\CRM\Service;

use Teknisa\Model\Util\NovoCodigo;
use Teknisa\CRM\Factory\ParceiroNegocioFactory;

class ger00045000ProspectService {
    
    protected $newCode;
    protected $prospectFactory;
    protected $leadFactory;
    protected $environment;
    protected $parceiroFactory;
    
    public function __construct ($prospectFactory, $newCode, $environment, $leadFactory, ParceiroNegocioFactory $parceiroFactory) {
        
        $this->prospectFactory   = $prospectFactory;
        $this->leadFactory       = $leadFactory;
        $this->parceiroFactory   = $parceiroFactory;
        $this->newCode           = $newCode;
        $this->environment       = $environment;
    }
    
    public function prepareInsertProspectEvolutionNextTask($row) {

        $row["NRSEQFILACONTA"] = $this->newCode->getCodeByTableName("FILACONTATO", $row["NRORG"]);
        $paramsInsertProspectEvolNextTask = array(
            "DSFILACONTATO"         => $row["DSFILACONTATO"],
            "DTPLANFILACONTA"       => $row["DTPLANFILACONTA"],
            "CDOPERREAL"            => $row["CDOPERREAL"],
            "NRSEQFILACONTA"        => $row["NRSEQFILACONTA"],
            "NRORG"                 => $row["NRORG"],
            "CRM_NRORGTRAB"         => empty($row["CRM_NRORGTRAB"]) ? $row["NRORG"] : $row["CRM_NRORGTRAB"],
            "NRORGINCLUSAO"         => $row["NRORG"],
            "CDOPERINCLUSAO"        => $row["CDOPEREVOL"],
            "NRPARCNEGOCIO"         => $row["NRPARCNEGOCIO"],
            "NRCONTATO"             => $row["NRSEQCONTATO"],
            "NRPRIORFILACONT"       => $row["NRPRIORFILACONT"],
            "NRSEQCONTATO"          => $row["NRSEQCONTATO"],
            "NRSEQCLASSIFICATAREFA" => empty($row['NRSEQCLASSIFICATAREFA']) ? '' : $row['NRSEQCLASSIFICATAREFA'],
            "NRSEQINTERLOCUTOR"     => empty($row['NRSEQINTERLOCUTOR']) ? '' : $row['NRSEQINTERLOCUTOR'],
            "DSEMAILTAREFA"         => empty($row['EMAILINTERLOC']) ? '' : $row['EMAILINTERLOC'],
            "DSTELEFONETAREFA"      => empty($row['NRTELEFONE1']) ? '' : $row['NRTELEFONE1'],
        );
        
        $this->prospectFactory->insertProspectEvolNextTask($paramsInsertProspectEvolNextTask);
        return $row["NRSEQFILACONTA"];
        
    }
    
    public function verificaTarefas($row) {
        
        $paramsVerificaTarefas = array(
            
            "NRPARCNEGOCIO"         => $row["NRPARCNEGOCIO"],
            "NRORG"                 => $row["NRORG"],
            "CRM_NRORGTRAB"         => !empty($row["CRM_NRORGTRAB"]) ? $row["CRM_NRORGTRAB"] : null
            
        );
        
        $retorno = $this->prospectFactory->verificaTarefas($paramsVerificaTarefas);
        if(count($retorno) > 0){
            return $retorno;
        }
        
        return false;
    }
    
    public function getOperador($cdoperador, $nrorg) {
        
        $paramsSelectOperador = array(
            "CDOPERREAL"            => $cdoperador,
            "NRORG"                 => $nrorg
        );
        
        $retorno = $this->prospectFactory->getOperador($paramsSelectOperador);
        
        if(!empty($retorno)){
            return $retorno[0]['NMOPERADOR'];
        }else{
            return false;
        }
        
        
    }
    
     public function getParceiro($parcnegocio, $nrorg) {
        
        $paramsSelectParceiro = array(
            "NRPARCNEGOCIO"           => $parcnegocio,
            "NRORG"                 => $nrorg
        );
        
        $retorno = $this->prospectFactory->getParceiro($paramsSelectParceiro);
        
        if(!empty($retorno)){
            return $retorno[0]['NMPRINCIPALPARC'];
        }else{
            return false;
        }
    }
    
    public function prepareSelectProspectContact($row) {
        $paramsSelectProspectContact = array(
            "NRPARCNEGOCIO"         => $row["NRPARCNEGOCIO"],
            "NRORG"                 => $row["NRORG"]
        );
        
        $retorno = $this->prospectFactory->selectProspectContact($paramsSelectProspectContact);
        if(count($retorno) > 0) {
            return $retorno[0];
        }else {
            if(isset($row['__is_new']) && !$row['__is_new']) {
                $razSoc;
                if(!empty($row['NMRAZSOCPROS'])) {
                    $razSoc = $row['NMRAZSOCPROS'];
                } else if(!empty($row['NMRAZSOCCLIE'])) {
                    $razSoc = $row['NMRAZSOCCLIE'];
                }
                
                $codigo = NovoCodigo::geraCodigo($row["NRORG"], "NRSEQCONTATO", 1, 10, false, true);
                $params = array(
                    "P_NRORG"           => $row["NRORG"],
                    "P_CDFILIAL"        => $this->environment->getCdFilial() ? $this->environment->getCdFilial() : "",
                    "P_NRCONTATO"       => $codigo,
                    "P_NRSEQCONTATO"    => intval($codigo),
                    "P_NRPARCNEGOCIO"   => $row["NRPARCNEGOCIO"],
                    "P_DSREFECONT"      => substr('Referente ao Lead '.$razSoc, 0, 59),
                    "P_IDSTATUSCONT"    => 'A',
                    "P_IDTPCONTATO"     => 'P',
                    "P_CDOPERADOR"      => $row['CDOPERINCLUSAO'],
                    "P_NRPARCNEGOCIO"   => $row['NRPARCNEGOCIO'],
                    "P_NRPRIORIDADE"    => 4
                );
                $this->prospectFactory->insertNewContact($params);
                
                $retorno = $this->prospectFactory->selectProspectContact($paramsSelectProspectContact);
                return $retorno[0];
            } else {
                return null;
            }
        }
        
        return array();
    }
    
    public function callForInsertNrseqcontatoForNewOpportunity($row) {
        
        $paramsUpdateOpportunity = array(
        
            "NRSEQOPORT"            => $row["NRSEQOPORT"],
            "NRSEQCONTATO"          => $row["NRSEQCONTATO"]
        
        );
        
        $this->prospectFactory->requestForInsertNrseqcontatoForNewOpportunity($paramsUpdateOpportunity);
        
    }
    
    public function callForUpdatePartnerType($row) {
        $paramsUpdatePartnerType = array(
            "P_NRPARCNEGOCIO"         => $row["NRPARCNEGOCIO"]
        );
        
        $this->prospectFactory->requestForUpdatePartnerType($paramsUpdatePartnerType);
        
    }
    
    public function callForInsertPartnershipOfTypeClient($row) {
        
        $nrParceria = $this->newCode->getCodeByTableName("PARCERIA", $row["NRORG"]);
        $cdOperador = $this->environment->getCdOperador();
        $nrorg      = $this->environment->getNrOrgTrab();
        $nrorgOper  = $this->environment->getNrOrg();
        
        $paramsInsertPartnership = array(
            "NRPARCERIA"            => $nrParceria,
            "NRPARCNEGOCIO"         => $row["NRPARCNEGOCIO"],
            "NRORG"                 => $nrorg,
            "NRORGOPER"             => $nrorgOper,
            "CDOPERADOR"            => $cdOperador
        );
        
        $this->prospectFactory->requestForInsertPartnershipOfTypeClient($paramsInsertPartnership);
        
    }
    
    public function callForInsertClient($row){
        
        $paramsInsertClient = array(
            
            "CDCLIENTE"             => isset($row["CDCLIENTE"]) ? $row["CDCLIENTE"] : null,
            "NRPARCNEGOCIO"         => isset($row["NRPARCNEGOCIO"]) ? $row["NRPARCNEGOCIO"] : null,
            "IDTPIJURCLIE"          => isset($row["IDTPIJURPROS"]) ? $row["IDTPIJURPROS"] : null,
            "NRINSJURCLIE"          => isset($row["NRINSJURPROS"]) ? $row["NRINSJURPROS"] : null,
            "NMRAZSOCCLIE"          => isset($row["NMRAZSOCPROS"]) ? $row["NMRAZSOCPROS"] : null,
            "NMFANTCLIE"            => isset($row["NMFANTPROS"]) ? $row["NMFANTPROS"] : null,
            "CDSEGMER"              => isset($row["CDSEGMER"]) ? $row["CDSEGMER"] : null,
            "NRINSESTCLIE"          => isset($row["NRINSESTPROS"]) ? $row["NRINSESTPROS"] : null,
            "NRFUNCCLIE"            => isset($row["NRFUNCPROS"]) ? $row["NRFUNCPROS"] : null,
            "VRFATUCLIE"            => isset($row["VRFATUPROS"]) ? $row["VRFATUPROS"] : null,
            "DSHOMEPACLI"           => isset($row["DSHOPAPROS"]) ? $row["DSHOPAPROS"] : null,
            "CDMODODIVULG"          => isset($row["CDMODODIVULG"]) ? $row["CDMODODIVULG"] : null,
            "CDATIVCLI"             => isset($row["CDATIVCLI"]) ? $row["CDATIVCLI"] : null,
            "NRORG"                 => isset($row["NRORG"]) ? $row["NRORG"] : null,
            "NRORGINCLUSAO"         => isset($row["NRORGINCLUSAO"]) ? $row["NRORGINCLUSAO"] : null,
            "CDOPERINCLUSAO"        => isset($row["CDOPERINCLUSAO"]) ? $row["CDOPERINCLUSAO"] : null
            
        );
        
        $this->prospectFactory->requestForInsertClient($paramsInsertClient);
        
    }
    
    public function callForDeactivateProspect($row) {
        $paramsUpdateProspect = array(
            "CDPROSPECT"            => $row["CDPROSPECT"]
        );
        
        $this->prospectFactory->requestForDeactivateProspect($paramsUpdateProspect);
    }
    
    public function callForInsertClientAddress($row) {
        
        $paramsInsertClientAddress = array(
            
            "CDCLIENTE"             => $row["CDCLIENTE"],
            "CDPAIS"                => $row["CDPAIS"],
            "SGESTADO"              => $row["SGESTADO"],
            "CDMUNICIPIO"           => $row["CDMUNICIPIO"],
            "CDBAIRRO"              => $row["CDBAIRRO"],
            "DSENDECLIE"            => $row["DSENDEPROS"],
            "IDTPENDECLIE"          => $row["IDTPENDEPROS"],
            "NMBAIRCLIE"            => $row["NMBAIRPROS"],
            "DSCOMPENDCLI"          => $row["DSCOMPENDPRO"],
            "NRCEPCLIE"             => $row["NRCEPPROS"],
            "NRTELECLIE"            => $row["NRTELEPROS"],
            "NRRAMALCLIE"           => $row["NRRAMALPROS"],
            "DSEMAILCLIE"           => $row["DSEMAILPROS"],
            "NRORG"                 => $row["NRORG"],
            "NRORGINCLUSAO"         => $row["NRORG"],
            "CDOPERINCLUSAO"        => $row["CDOPERADOR"],
            "NRENDERECOPARC"        => $row["NRENDERECOPARC"]
        );
        
        $this->prospectFactory->requestForInsertClientAddress($paramsInsertClientAddress);
        
    }
    
    public function callForSelectAddressProspect($row) {
        
        $paramsSelectProspectAddress = array(
            
            "CDPROSPECT"            => $row["CDPROSPECT"],
            "NRORG"                 => $row["NRORG"]
            
        );
        
        $returnedAddress = $this->prospectFactory->requestForSelectProspectAddress($paramsSelectProspectAddress);
        return $returnedAddress;
    }
    
    public function callForSetTaskEndDate($row) {
        
        $paramsSetTaskEndDate = array(
            
            "NRSEQFILACONTA"        => $row["NRSEQFILACONTA"]
            
        );
        
        $this->prospectFactory->requestForSetTaskEndDate($paramsSetTaskEndDate);
        
    }
    
    public function callForDeactivateProspectTask($taskUpdateParams){
        
        $this->prospectFactory->requestForDeactivateProspectTask($taskUpdateParams);
        
    }
    
    public function replicaInterlocutorProspect($row) {
        
        $nrparcnegocioInterlocutor = $this->prospectFactory->getInterlocutorParc($row['NRRELACIONAPARC'], $row['NRORG']);
        if($row['REPLICAENDERECO'] == true){
            $nrenderecoparcInterlocutor = $this->prospectFactory->getEnderecoparcInterlocutor($nrparcnegocioInterlocutor, $row['NRORG']);
            if($nrenderecoparcInterlocutor){
                $paramsUpdate = array(
                    "CDTIPOENDERECO" => $row['IDENDEINPROS'] == 'R' ? 'OUTROS' : 'COMERCIAL' ,
                    "NRORGULTATU" => $row['NRORG'],
                    "CDOPERULTATU" => $row['CODOPERLOGGED'],
                    "CDPAIS" => $row['CDPAIS'],
                    "SGESTADO" => $row['SGESTADO'],
                    "CDMUNICIPIO" => isset($row['CDMUNICIPIO']) ? $row['CDMUNICIPIO'] : '',
                    "CDBAIRRO" => isset($row['CDBAIRRO']) ? $row['CDBAIRRO'] : '',
                    "NMBAIRROENDERECO" => $row['NMBAIRINPROS'],
                    "DSENDERECO" => $row['DSENDEINPROS'],
                    "NRCEPENDERECO" => $row['NRCEPINPROS'],
                    "NRPARCNEGOCIO" => $nrparcnegocioInterlocutor,
                    "NRORG" => $row['NRORG'],
                    "NRENDERECOPARC" => $nrenderecoparcInterlocutor
                );
                $this->prospectFactory->replicaEnderecoparcInterlocutor($paramsUpdate);
            }else{
                $paramsInsert = array(
                    "IDATIVO" => $row['IDATIVO'],
                    "NRPARCNEGOCIO" => $nrparcnegocioInterlocutor,
                    "NRORG" => $row['NRORG'],
                    "NRENDERECOPARC" => $this->newCode->getCodeByTableName("ENDERECOPARC", $row["NRORG"]),
                    "CDTIPOENDERECO" => $row['IDENDEINPROS'] == 'R' ? 'OUTROS' : 'COMERCIAL',
                    "NRORGINCLUSAO" => $row['NRORG'],
                    "CDOPERINCLUSAO" => $row['CODOPERLOGGED'],
                    "CDPAIS" => $row['CDPAIS'],
                    "SGESTADO" => $row['SGESTADO'],
                    "CDMUNICIPIO" => isset($row['CDMUNICIPIO']) ? $row['CDMUNICIPIO'] : '',
                    "CDBAIRRO" => isset($row['CDBAIRRO']) ? $row['CDBAIRRO'] : '',
                    "NMBAIRROENDERECO" => $row['NMBAIRINPROS'],
                    "DSENDERECO" => $row['DSENDEINPROS'],
                    "NRCEPENDERECO" => $row['NRCEPINPROS'],
                    "DSCOMPLEENDERECO" => '',
                    "NRIMOVELENDERECO" => ''
                );
                $this->prospectFactory->insertEnderecoparc($paramsInsert);
            }
        }
    }
    
    public function setIdQualificadoProspect($row) {
        
        $paramsSetQualification = array(
            
            "IDQUALIFICADO"         => $row['IDQUALIFICADO'],
            "NRPARCNEGOCIO"         => $row["NRPARCNEGOCIO"],
            "NRORG"                 => $row["NRORG"],
            "CRM_NRORGTRAB"         => isset($row["CRM_NRORGTRAB"]) ? $row["CRM_NRORGTRAB"] : null
        );
        
        $this->prospectFactory->setIdQualificadoProspect($paramsSetQualification);
        
    }
    
    public function insertConcorrProspect($row) {
        
        $paramsInsertConcorrParc = array(
            
            "NRCONCORRPROSPECT"     => $row["NRCONCORRPROSPECT"],
            "CDPROSPECT"            => $row["CDPROSPECT"],
            "NRCONCORRENTE"         => $row["NRCONCORRENTE"],
            "NRORG"                 => $row["NRORG"],
            "DTINIVIGENCIA"         => $row["DTINIVIGENCIA"],
            "DTFIMVIGENCIA"         => $row["DTFIMVIGENCIA"],
            "CDOPERINCLUSAO"        => $row["CODOPERLOGGED"]
            
        );
        
        $this->prospectFactory->insertConcorrProspect($paramsInsertConcorrParc);
        
    }  
    
    public function updateConcorrProspect($row) {
        
        $paramsUpdateConcorrParc = array(
            
            "NRCONCORRPROSPECT"     => $row["NRCONCORRPROSPECT"],
            "NRORG"                 => $row["NRORG"],
            "NRCONCORRENTE"         => $row["NRCONCORRENTE"],
            "DTINIVIGENCIA"         => $row["DTINIVIGENCIA"],
            "DTFIMVIGENCIA"         => $row["DTFIMVIGENCIA"]
            
        );
        
        $this->prospectFactory->updateConcorrProspect($paramsUpdateConcorrParc);
        
    }
    
    public function deleteConcorrProspect($row) {
        
        $paramsDeleteConcorrParc = array(
            
            "NRCONCORRPROSPECT"     => $row["NRCONCORRPROSPECT"],
            "NRORG"                 => $row["NRORG"]
            
        );
        
        $this->prospectFactory->deleteConcorrProspect($paramsDeleteConcorrParc);
        
    }
    
    public function validaCNPJCliente($row){
        
        $paramsSelectClient = array(
            "CNPJ"          => $row["CNPJ"],
            "NRORG"         => $row["NRORG"],
            "CRM_NRORGTRAB" => $row["CRM_NRORGTRAB"]
        );
        
        $returnedClients = $this->prospectFactory->validaCNPJCliente($paramsSelectClient);
        if(isset($returnedClients[0])){
            return $returnedClients;
        }else{
            return true;
        }
    }
    
    public function createPartnership($row) {
        $nrParcnegocio = $row['NRPARCNEGOCIO'];
        $nrparceiro = $row['NRPARCERIA'];
        $nrOrg = $row['NRORG'];
        $cdoperinclusao = $row['CDOPERINCLUSAO'];
        $cdtipoparceiro = $row["CDTIPOPARCEIRO"]; 
        $params = array(
          "NRPARCERIA"     => $nrparceiro,
          "NRORG"          => $nrOrg,
          "NRPARCNEGOCIO"  => $nrParcnegocio,
          "CDTIPOPARCEIRO" => $cdtipoparceiro,
          "IDATIVO"        => 'S',
          "CDOPERINCLUSAO" => $cdoperinclusao,
          "NRORGINCLUSAO"  => $nrOrg);
        
        $this->prospectFactory->createPartnership($params);
    }
    
    public function setParceiroNegocio($row, $parcCriado) {
        try {
            $params = array (
                "IDATIVO"               => $row["IDATIVO"],
                "NRPARCNEGOCIO"         => $row["NRPARCNEGOCIO"],
                "NRORG"                 => $row["NRORG"],
                "NMPRINCIPALPARC"       => $row["NMRAZSOCPROS"],
                "NMSECUNDARIPARC"       => empty($row["NMFANTPROS"]) ? $row["NMRAZSOCPROS"] : $row["NMFANTPROS"] ,
                "NRINSCRICAOPARC"       => $row["NRINSJURPROS"],
                "NRORGINCLUSAO"         => $row["NRORG"],
                "CDOPERINCLUSAO"        => $row["CDOPERINCLUSAO"],
                "CDTIPOPARCPRINCIPAL"   => "PROSPECT",
                "CDTIPOINSCRICAO"       => $row["TIPOINSC"],
                "IDPESSOAFISICA"        => $row["ISCPF"],
            );
            if(!$parcCriado) {
                $this->prospectFactory->setParceiroNegocio($params);
            }
            $params['CRM_NRORGTRAB'] = $row['CRM_NRORGTRAB'];
            $params['CDTIPOPARCEIRO'] = $row['CDTIPOPARCEIRO'];
            $params['CDOPERRESPONSAVEL'] = $row['CDOPERRESPONSAVEL'];
            $params['NRPARCRESP'] = $row['NRPARCRESP'];
            $params['IDSTATUS'] = null;
            $retorno = $this->leadFactory->insertStatusParc($params);
            
            return $retorno;
        } catch(\Exception $e) {
            throw $e;
        };
    }

    public function newContato($row) {
        
        $paramsVerifyFilial = array(
            "CDOPERINCLUSAO"        => $row['CDOPERINCLUSAO'],
            "NRORG"                 => $row['NRORG']
        );
        
        $filial = $this->prospectFactory->verifyFilialOper($paramsVerifyFilial);
        
        $params = array(

            "DSREFECONT"    => substr('Referente ao Lead '.$row['NMRAZSOCPROS'], 0, 59),
            "NRPARCNEGOCIO" => $row['NRPARCNEGOCIO'],
            "NRSEQCONTATO"  => $row['NRSEQCONTATO'],
            "CDOPERCONT"    => $row['CDOPERINCLUSAO'],
            "NRCONTATO"     => $row['NRCONTATO'],
            "CDFILIAL"      => $row['CDFILIAL'],
            "NRORG"         => $row['NRORG'],
            "IDSTATUSCONT"  =>'A',
            "IDTPCONTATO"   =>'P'

        );
        
        $this->prospectFactory->newContato($params);
    }
    
    function isParamOperDifEditEvolActive($row) {
        $nrorg = $this->environment->getNrOrgTrab();
        
        $params = array(
            "NRORG" => $nrorg
        );
        
        $isActive = $this->prospectFactory->isParamOperDifEditEvolActive($params);
        return $isActive[0]['OPERDIFEVOL'] === 'S';
    }
    
    function operToEditIsTheSame($row) {
        $cdoperador = $this->environment->getCdOperador();
        $nrorg = $this->environment->getNrOrgTrab();
        
        $params = array(
            "NRORG"         => $nrorg,
            "NRSEQEVOLCONT"    => $row['NRSEQEVOLCONT'],
            "CDOPERADOR"    => $cdoperador
        );
        
        $isSameOper = $this->prospectFactory->operToEditIsTheSame($params);
        
        return $isSameOper[0]['SAMEOPERADOR'] === 'S';
    }
    
    function callForInsertAllAddresses($row) {
        if(!empty($row['CDPROSPECT'])) {
            $addresses = $this->callForSelectAddressProspect($row);
            foreach($addresses as $address) {
                $rowWithAddress = array_merge((array)$row, $address);
                
                $this->callForInsertClientAddress($rowWithAddress);
            }
        }
    }
    
    public function verificaParceiro($params) {
        return $this->leadFactory->verificaParceiro($params);
    }
    
    public function updateClientWithoutNrParcNegocio($params) {
        $this->leadFactory->updateClientWithoutNrParcNegocio($params['NRINSJURCLIE'], $params['NRORG'], $parms['NMRAZSOCCLIE']);
    }
    
    public function verificaCliente($nrparcnegocio, $nrorg, $nrinscricaoparc) {
        $cliente = $this->prospectFactory->verificaCliente($nrparcnegocio, $nrorg, $nrinscricaoparc);
        if(empty($cliente)) {
            return false;
        } else {
            return $cliente;
        }
    }
    
    public function updateStatusClie($row) {
        return $this->prospectFactory->updateStatusClie($row);
    }
    
    public function getCdOperador($key, $find = "OPERADOR") {
        return $this->parceiroFactory->getCdOperador($key, $find);
    }
    
    public function pesquisaParceiro($filter) {
        $filtro = array(
            'IDTPOPERADOR' => '',
            'NRORG' => '',
            'P_CRM_NRORGTRAB' => '',
            'NRREVENDA' => ''
        );
        foreach($filter as $filt) {
            if($filt['columnName'] == 'IDTPOPERADOR') {
                $filtro['IDTPOPERADOR'] = $filt['value'];
            }
            if($filt['columnName'] == 'NRORG') {
                $filtro['NRORG'] = $filt['value'];
            }
            if($filt['columnName'] == 'P_CRM_NRORGTRAB') {
                $filtro['P_CRM_NRORGTRAB'] = $filt['value'];
            }
            if($filt['columnName'] == 'NRREVENDA') {
                $filtro['NRREVENDA'] = $filt['value'];
            }
            if($filt['columnName'] == 'CDTIPOPARCPRINCIPAL') {
                $filtro['CDTIPOPARCPRINCIPAL'] = $filt['value'];
            }
            if($filt['columnName'] == 'CDOPERRESP') {
                $filtro['CDOPERRESP'] = $filt['value'];
            }
        }
        return $this->prospectFactory->pesquisaParceiro($filtro);
    }
    
    public function fundeParceiro($row) {
        $this->leadFactory->fundeParceiro($row);
    }
    
    public function desativarStatusParc($row) {
        $this->leadFactory->desativarStatusParc($row);
    }
    
    public function alteraAtivoStatusParc($row) {
        $this->leadFactory->alteraAtivoStatusParc($row);
    }
    
    public function insertStatus($row) {
        $this->leadFactory->insertStatusParc($row);
    }
    
    public function getProspect($row) {
        $params = array(
            'NRPARCNEGOCIO' => $row['NRPARCNEGOCIO'],
            'NRORG' => $row['NRORG']
        );
        
        return $this->prospectFactory->getProspect($params);
    }
    
    public function getLead($row) {
        $params = array(
            'NRPARCNEGOCIO' => $row['NRPARCNEGOCIO'],
            'NRORG' => $row['NRORG']
        );
        
        return $this->prospectFactory->getLead($params);
    }
}
?>