<?php
namespace Teknisa\CRM\Util;

use Zeedhi\Framework\DTO\Request\Row;
use Zeedhi\Framework\DTO\Response;
use Zeedhi\Framework\DTO\Response\Message;
use Teknisa\Libs\Util\Address;
use Zeedhi\Framework\DataSource\DataSet;
use Doctrine\ORM\EntityManager;
use Teknisa\Libs\Util\NewCode;
use Teknisa\Libs\Util\Environment;
use Zeedhi\Framework\DTO\Request\Filter;
use Zeedhi\Framework\DataSource\FilterCriteria;


class Util
{
    const EXPRESSAO_NUMEROS = '/[^0-9]/';
    
    protected $address;
    protected $confirmaEnderecoService;
    protected $environment;
    
     public function __construct($address, $confirmaEnderecoService, $environment) {
        $this->address = $address;
        $this->confirmaEnderecoService = $confirmaEnderecoService;
        $this->environment = $environment;
    }
   
    
    private static $caracteres_invalidos = array(
        "ª" => "", "º" => "", "à" => "a","á" => "a","ã" => "a","â" => "a","é" => "e","ê" => "e","ì" => "i","í" => "i",
        "ó" => "o", "õ" => "o","ô" => "o","ú" => "u","ü" => "u","ç" => "c","À" => "A","Á" => "A","Ã" => "A","Â" => "A",
        "É" => "E","Ê" => "E","Í" => "I","Ó" => "O","Õ" => "O","Ô" => "O","Ù" => "U","Ú" => "U","Ü" => "U", " " => "_",
        "." => "", "-" => ""
    );
    
    private static $caracteres_especiais = array(
        "ª" => "", "º" => "", "à" => "a","á" => "a","ã" => "a","â" => "a","é" => "e","ê" => "e","ì" => "i","í" => "i",
        "ó" => "o", "õ" => "o","ô" => "o","ú" => "u","ü" => "u","ç" => "c","À" => "A","Á" => "A","Ã" => "A","Â" => "A",
        "É" => "E","Ê" => "E","Í" => "I","Ó" => "O","Õ" => "O","Ô" => "O","Ù" => "U","Ú" => "U","Ü" => "U"
    );
    
    public static function removeCaracteresInvalidos($str){
        return strtr($str, self::$caracteres_invalidos);
    }
    
    public static function removeCaracteresEspeciais($str){
        return strtr($str, self::$caracteres_especiais);
    }
    
    public static function getTipoInscricao($nrinscricao, $tabela = null) {
        $nrinscricao = self::getSomenteNumeros($nrinscricao);
        
        switch (strlen($nrinscricao)) {
            case 5:
                if ($tabela == 'CRM_CANDIDATO')
                    return "O";
                else
                    return "CODIGO";
              break;

            case 11:
                if ($tabela == 'CRM_CANDIDATO')
                    return "F";
                else
                    return "CPF";
              break;

            case 14:
                if ($tabela == 'CRM_CANDIDATO')
                    return "J";
                else
                    return "CNPJ";
              break;

            case 20:
                if ($tabela == 'CRM_CANDIDATO')
                    return "I";
                else
                    return "LIVRE";
              break;

            default:
                if ($tabela == 'CRM_CANDIDATO')
                    return "O";
                else
                    return "CODIGO";
              break;

        }
    }
    
    public static function getSomenteNumeros($value) {
        return preg_replace(self::EXPRESSAO_NUMEROS, "", $value);
    }
    
    public static function getDataAtual($format = 'd/m/Y') {
        $date = new \DateTime();
        return $date->format($format);
    }
    
    public function findAddress(Row $row, Response $response){
        
        $this->address->findAddress($row, $response);
        if(!empty($response->getDataSets())){
            $foundAddress = $response->getDataSets()[0]->getRows();
            $foundAddress = $this->confirmaEnderecoService->confirmAddress($foundAddress);
            if(!empty($foundAddress['MESSAGES'])){
                $response->addMessage(new Message($foundAddress['MESSAGES'], Message::TYPE_WARNING));        
            }
            $response->addDataSet(new DataSet('ENDERECO', $foundAddress['ADDRESS']));        
        }
    
    }
    
    public static function encrypt($decryptedPassword) {
        $connectionFactory = new \Zeedhi\Framework\ORM\ConnectionFactory();
        return $connectionFactory->encrypt($decryptedPassword);
    }
    
    public static function decrypt($encryptedPassword) {
        $connectionFactory = new \Zeedhi\Framework\ORM\ConnectionFactory();
        return $connectionFactory->decrypt($encryptedPassword);
    }
    
    public static function getRequestFilters($request) {
        $filterCriteria = $request->getFilterCriteria();
        $filters = $filterCriteria->getConditions();
        
        return $filters;
    }
    
    public static function removeRequestFilters($request, $filtersToRemove) {
        if(!is_array($filtersToRemove)) {
            $filtersToRemove = [$filtersToRemove];
        }
        
        $allFilters = self::getRequestFilters($request);
        
        $indexesToRemove = [];
        
        foreach($filtersToRemove as $filterToRemove) {
            foreach($allFilters as $key => $filter) {
                if($filter['columnName'] == $filterToRemove) {
                    array_splice($allFilters, $key, 1);
                }
            }
        }
        
        $newReq = self::createNewFilterRequest($request, $allFilters);
            
        return $newReq;
    }
    
    public static function addRequestFilters($request, $filtersToAdd) {
        if(!is_array($filtersToAdd)) {
            $filtersToAdd = [$filtersToAdd];
        }
        
        $allFilters = self::getRequestFilters($request);
        
        $allFilters = array_merge($allFilters, $filtersToAdd);
        $newReq = self::createNewFilterRequest($request, $allFilters);
        
        return $newReq;
    }
    
    public static function editRequestFilters($request, $filterName, $newFilter) {
        
        $request = self::removeRequestFilters($request, $filterName);
        $request = self::addRequestFilters($request, [$newFilter]);
        
        return $request;
    }
    
    public static function findFilter($request, $filterName) {
        $filters = self::getRequestFilters($request);
        
        foreach($filters as $filter) {
            if($filter['columnName'] == $filterName) {
                return $filter;
            }
        }
        
        return null;
    }
    
    public static function findFilterValue($request, $filterName) {
        $filter = self::findFilter($request, $filterName);
        
        return $filter !== null ? $filter['value'] : null;
    }
    
    public static function createNewFilterRequest($request, $newFilter) {
        $criteria = $request->getFilterCriteria();
        
        $newCriteria = new FilterCriteria($criteria->getDataSourceName(),
            $newFilter, $criteria->getPage(), $criteria->getPageSize());
        
        $newReq = new Filter($newCriteria, $request->getMethod(),
            $request->getRoutePath(), $request->getUserId());
            
        return $newReq;
    }
    
    public function stringfyArray($array) {
        $stringfiedArray = "_";
        
        if(is_array($array)) {
            foreach($array as $node) {
                $stringfiedArray .= "${node}_";
            }
        } else {
            $stringfiedArray = NULL;
        }
        
        return $stringfiedArray;
    }
    
    public function setAuditColumns($row) {
        $cdoperador = $this->environment->getCdOperador();
        $nrorgOper  = $this->environment->getNrorg();
        
        $row['DTULTATU']     = (new \DateTime)->format('d/m/Y H:i:s'); //SYSDATE
        $row['CDOPERULTATU'] = $cdoperador;
        $row['NRORGULTATU']  = $nrorgOper;
    }
    
    public function modifyDateFilter($request, $dateFilterName, $dtiniName = 'P_DTINICIO', $dtfimName = 'P_DTFIM') {
        $dateFilter = self::findFilterValue($request, $dateFilterName);
        
        if($dateFilter !== null) {
            $startFilter = array(
                "columnName" => $dtiniName,
                "operator"   => '=',
                "value"      => $dateFilter[0]
            );
            
            $endFilter = array(
                "columnName" => $dtfimName,
                "operator"   => '=',
                "value"      => $dateFilter[1]
            );
            
            $request = self::addRequestFilters($request, [$startFilter, $endFilter]);
            $request = self::removeRequestFilters($request, $dateFilterName);
        }
        
        return $request;
    }
}